.. Workflow Templates for Reproducible for Data Analysis Benchmarks documentation master file, created by
   sphinx-quickstart on Fri Jun 21 10:32:15 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Workflow Templates for Reproducible for Data Analysis Benchmarks's documentation!
============================================================================================

.. include:: ./readme.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   workflow
   benchmark

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
